/*  Filename: OptionsDialog.js
 * $Revision: 1.7 $
 *     $Date: 2009/03/01 00:13:27 $
 *
 * Script file for Options dialog. Loads language lists to drop-down menus.
 * 
 * ***** BEGIN LICENSE BLOCK *****
 * Version: MPL 1.1/GPL 2.0/LGPL 2.1
 *
 * The contents of this file are subject to the Mozilla Public License Version
 * 1.1 (the "License"); you may not use this file except in compliance with
 * the License. You may obtain a copy of the License at
 * http://www.mozilla.org/MPL/
 *
 * Software distributed under the License is distributed on an "AS IS" basis,
 * WITHOUT WARRANTY OF ANY KIND, either express or implied. See the License
 * for the specific language governing rights and limitations under the
 * License.
 *
 * The Original Code is TabLang extension for Mozilla Firefox.
 *
 * The Initial Developer of the Original Code is Andrey Lokot.
 * Portions created by the Initial Developer are Copyright (C) 2008
 * the Initial Developer. All Rights Reserved.
 *
 * Contributor(s):
 *   Andrey Lokot <crazy-eye@yandex.ru>
 *
 * Alternatively, the contents of this file may be used under the terms of
 * either the GNU General Public License Version 2 or later (the "GPL"), or
 * the GNU Lesser General Public License Version 2.1 or later (the "LGPL"),
 * in which case the provisions of the GPL or the LGPL are applicable instead
 * of those above. If you wish to allow use of your version of this file only
 * under the terms of either the GPL or the LGPL, and not to allow others to
 * use your version of this file under the terms of the MPL, indicate your
 * decision by deleting the provisions above and replace them with the notice
 * and other provisions required by the GPL or the LGPL. If you do not delete
 * the provisions above, a recipient may use your version of this file under
 * the terms of any one of the MPL, the GPL or the LGPL.
 *
 * ***** END LICENSE BLOCK ***** */

var switcher = Components.classes["tablang@mozdev.org/tablangswitcher;1"]
				.getService(Components.interfaces.ITabLangSwitcher);
var options = Components.classes["tablang@mozdev.org/tablangservice;1"]
				.getService().wrappedJSObject.options;

// fillWithCurrentLang() retrieves current system language and
// sets corresponding menuitem for menu with "langMenuId" id
function fillWithCurrentLang(langMenuId) {
	var langMenu = document.getElementById(langMenuId);
	langMenu.selectedItem = document.getElementById(langMenuId
		+ "-lang" + switcher.GetCurrentLangId().toString(16));
	// Synchronizing langMenu value to preferences store
	var event = document.createEvent("Event");
	event.initEvent("change", true, false);
	langMenu.dispatchEvent(event);
}

// generateLangMenu() generates drop-down menu with
// available languages for langMenu (menulist DOM element)
function generateLangMenu(langMenu) {
	for each (lang in options.langList) {
		var newLang = document.createElement("menuitem");
		// TODO: actual language names in Windows
		var label = lang;
		if (switcher.GetPlatform() == switcher.TABLANG_IMP_WIN) {
			label = label.replace(/\s0x\d{8}/i, "");
		}
		newLang.setAttribute("label", label);
		newLang.setAttribute("value", lang);
		newLang.setAttribute("id", langMenu.id + "-lang"
			+ switcher.LangIdFromTag(lang).toString(16));
		langMenu.menupopup.appendChild(newLang);
		if (langMenu.value == newLang.value) {
			langMenu.selectedItem = newLang;
		}
	}
}

// onOptionsLoad() initializes preferences dialog
function onOptionsLoad() {
	// Creating drop-down menu for each property
	generateLangMenu(document.getElementById("defaultLangMenu"));
	generateLangMenu(document.getElementById("urlbarLangMenu"));
}

window.addEventListener("DOMContentLoaded", function(event) { onOptionsLoad(); }, false);
